==> 2.4.11.tar.gz: cloudlog/application/language/greek/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Προσοχή: πρέπει να ορίσετε μια ενεργή θέση σταθμού.';

$lang['notice_turn_the_radio_on'] = 'Δεν έχετε κάνει κανένα QSO σήμερα. ώρα να ανοίξετε τον ασύρματο!';

$lang['general_word_important'] = 'Σημαντικό';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Πληροφορίες';
$lang['general_word_choose_file'] = 'Επιλογή αρχείου';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Ημερομηνία';
$lang['general_word_time'] = 'Ωρα';
$lang['general_word_datetime'] = 'Ημερομηνία/Ωρα';
$lang['general_word_none'] = 'None';
$lang['general_word_name'] = 'όνομα';
$lang['general_word_location'] = 'Τοποθεσία';
$lang['general_word_comment'] = 'Σχόλιο';
$lang['general_word_general'] = 'Γενικα';
$lang['general_word_satellite'] = 'Δορυφόρος';
$lang['general_word_satellite_short'] = 'Δορ';
$lang['general_word_notes'] = 'Σημειώσεις';
$lang['general_word_country'] = 'Χώρα';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Σύνολο';
$lang['general_word_year'] = 'Ετος';
$lang['general_word_month'] = 'Μήνας';

$lang['general_word_worked'] = 'Worked';
$lang['general_word_confirmed'] = 'Επιβεβαιωμένο';
$lang['general_word_needed'] = 'Απαιτείται';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Οχι';
$lang['general_word_yes'] = 'Ναι';
$lang['general_word_method'] = 'Μέθοδος';

$lang['general_word_sent'] = 'Απεσταλμένα';
$lang['general_word_received'] = 'Ελήφθη';
$lang['general_word_requested'] = 'Έχει  ζητηθεί';
$lang['general_word_queued'] = 'Σε ουρά';
$lang['general_word_invalid_ignore'] = 'Μη έγκυρο (Αγνόησή)';
$lang['general_word_qslcard'] = 'Κάρτa QSL';
$lang['general_word_qslcard_management'] = 'QSL Management';
$lang['general_word_qslcards'] = 'Κάρτες QSL';
$lang['general_word_qslcard_direct'] = 'Απευθείας';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Ηλεκτρονική';
$lang['general_word_qslcard_manager'] = 'Διευθυντής';
$lang['general_word_qslcard_via'] = 'Μέσω';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'Κάρτες eQSL';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Επεξεργασία QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Σημείωση QSL ως Ελήφθη (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Σημείωση QSL ως Ελήφθη (Απευθείας)';
$lang['general_mark_qsl_rx_electronic'] = 'Σημείωση QSL ως Ελήφθη (Ηλεκτρονικός)';
$lang['general_mark_qsl_tx_bureau'] = 'Σημείωση QSL ως απεσταλμένο (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Σημείωση QSL ως απεσταλμένο (Απευθείας)';
$lang['general_mark_qsl_requested'] = 'Σημείωση QSL ζητήθηκε';
$lang['general_mark_qsl_requested_bureau'] = 'Σημείωση QSL ζητήθηκε (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Σημείωση QSL ζητήθηκε (Απευθείας)';
$lang['general_mark_qsl_not_required'] = 'Σημείωση QSL μη απαραίτητο';

$lang['general_delete_qso'] = 'Διαγραφή QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Συνολική Απόσταση';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Τοποθεσία Σταθμού';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Σταθμός';

$lang['gen_hamradio_call'] = 'Δια';
$lang['gen_hamradio_callsign'] = 'Διακριτικό';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Τρόπος';
$lang['gen_hamradio_rst_sent'] = 'Απεσταλμένα';
$lang['gen_hamradio_rst_rcvd'] = 'Ελήφθη\'d';
$lang['gen_hamradio_band'] = 'Ζώνη';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Ζώνη (RX)';
$lang['gen_hamradio_frequency'] = 'Συχνότητα';
$lang['gen_hamradio_frequency_rx'] = 'Συχνότητα (RX)';
$lang['gen_hamradio_radio'] = 'Ραδιόφωνο';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Τοποθετών';
$lang['gen_hamradio_transmit_power'] = 'Ισχύ διαβίβασης (W)';
$lang['gen_hamradio_propagation_mode'] = 'Λειτουργία διάδοσης';

$lang['gen_hamradio_satellite_name'] = 'Όνομα δορυφόρου';
$lang['gen_hamradio_satellite_mode'] = 'Λειτουργία δορυφόρου';

$lang['gen_hamradio_logbook'] = 'Αρχείο επαφών';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'Επαρχία ΗΠΑ';
$lang['gen_hamradio_county_reference'] = 'Κομητεία ΗΠΑ ';
$lang['gen_hamradio_iota_reference'] = 'Παραπομπή IOTA';
$lang['gen_hamradio_sota_reference'] = 'Παραπομπή SOTA';
$lang['gen_hamradio_wwff_reference'] = 'Παραπομπή WWFF';
$lang['gen_hamradio_pota_reference'] = 'Παραπομπή POTA';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Επαρχία';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Χειριστής';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Έχετε';
$lang['dashboard_qsos_today'] = 'Σημερινά QSOs ';
$lang['dashboard_qso_breakdown'] = 'QSOs Αναλυτικά';
$lang['dashboard_countries_breakdown'] = 'Χώρες Αναλυτικά';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Από την ημερομηνία';

$lang['gen_this_qso_was_confirmed_on'] = 'Αυτό το QSO επιβεβαιώθηκε στις';

$lang['error_no_logbook_found'] = 'Δεν βρέθηκαν αρχεία. Πρέπει να ορίσετε ένα αρχεία στα αρχεία σταθμών! Κάντε το εδώ:';

$lang['copy_to_clipboard'] = 'Αντιγραφή στο πρόχειρο';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

==> 2.5.2.tar.gz: cloudlog/application/language/greek/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Προσοχή: πρέπει να ορίσετε μια ενεργή θέση σταθμού.';

$lang['notice_turn_the_radio_on'] = 'Δεν έχετε κάνει κανένα QSO σήμερα. ώρα να ανοίξετε τον ασύρματο!';

$lang['general_word_important'] = 'Σημαντικό';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Πληροφορίες';
$lang['general_word_choose_file'] = 'Επιλογή αρχείου';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";

$lang['general_word_date'] = 'Ημερομηνία';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Ωρα';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Ημερομηνία/Ωρα';
$lang['general_word_none'] = 'None';
$lang['general_word_name'] = 'όνομα';
$lang['general_word_location'] = 'Τοποθεσία';
$lang['general_word_comment'] = 'Σχόλιο';
$lang['general_word_general'] = 'Γενικα';
$lang['general_word_satellite'] = 'Δορυφόρος';
$lang['general_word_satellite_short'] = 'Δορ';
$lang['general_word_notes'] = 'Σημειώσεις';
$lang['general_word_country'] = 'Χώρα';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Σύνολο';
$lang['general_word_year'] = 'Ετος';
$lang['general_word_month'] = 'Μήνας';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Worked';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Επιβεβαιωμένο';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'Απαιτείται';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Οχι';
$lang['general_word_yes'] = 'Ναι';
$lang['general_word_method'] = 'Μέθοδος';

$lang['general_word_sent'] = 'Απεσταλμένα';
$lang['general_word_received'] = 'Ελήφθη';
$lang['general_word_requested'] = 'Έχει  ζητηθεί';
$lang['general_word_queued'] = 'Σε ουρά';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Μη έγκυρο (Αγνόησή)';
$lang['general_word_qslcard'] = 'Κάρτa QSL';
$lang['general_word_qslcard_management'] = 'QSL Management';
$lang['general_word_qslcards'] = 'Κάρτες QSL';
$lang['general_word_qslcard_direct'] = 'Απευθείας';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Ηλεκτρονική';
$lang['general_word_qslcard_manager'] = 'Διευθυντής';
$lang['general_word_qslcard_via'] = 'Μέσω';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'Κάρτες eQSL';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Επεξεργασία QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Σημείωση QSL ως Ελήφθη (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Σημείωση QSL ως Ελήφθη (Απευθείας)';
$lang['general_mark_qsl_rx_electronic'] = 'Σημείωση QSL ως Ελήφθη (Ηλεκτρονικός)';
$lang['general_mark_qsl_tx_bureau'] = 'Σημείωση QSL ως απεσταλμένο (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Σημείωση QSL ως απεσταλμένο (Απευθείας)';
$lang['general_mark_qsl_requested'] = 'Σημείωση QSL ζητήθηκε';
$lang['general_mark_qsl_requested_bureau'] = 'Σημείωση QSL ζητήθηκε (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Σημείωση QSL ζητήθηκε (Απευθείας)';
$lang['general_mark_qsl_not_required'] = 'Σημείωση QSL μη απαραίτητο';

$lang['general_delete_qso'] = 'Διαγραφή QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Συνολική Απόσταση';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Τοποθεσία Σταθμού';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Σταθμός';

$lang['gen_hamradio_call'] = 'Δια';
$lang['gen_hamradio_callsign'] = 'Διακριτικό';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Τρόπος';
$lang['gen_hamradio_rst_sent'] = 'Απεσταλμένα';
$lang['gen_hamradio_rst_rcvd'] = 'Ελήφθη\'d';
$lang['gen_hamradio_band'] = 'Ζώνη';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Ζώνη (RX)';
$lang['gen_hamradio_frequency'] = 'Συχνότητα';
$lang['gen_hamradio_frequency_rx'] = 'Συχνότητα (RX)';
$lang['gen_hamradio_radio'] = 'Ραδιόφωνο';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Τοποθετών';
$lang['gen_hamradio_transmit_power'] = 'Ισχύ διαβίβασης (W)';
$lang['gen_hamradio_propagation_mode'] = 'Λειτουργία διάδοσης';

$lang['gen_hamradio_satellite_name'] = 'Όνομα δορυφόρου';
$lang['gen_hamradio_satellite_mode'] = 'Λειτουργία δορυφόρου';

$lang['gen_hamradio_logbook'] = 'Αρχείο επαφών';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'Επαρχία ΗΠΑ';
$lang['gen_hamradio_county_reference'] = 'Κομητεία ΗΠΑ ';
$lang['gen_hamradio_iota_reference'] = 'Παραπομπή IOTA';
$lang['gen_hamradio_sota_reference'] = 'Παραπομπή SOTA';
$lang['gen_hamradio_wwff_reference'] = 'Παραπομπή WWFF';
$lang['gen_hamradio_pota_reference'] = 'Παραπομπή POTA';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Επαρχία';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Χειριστής';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Έχετε';
$lang['dashboard_qsos_today'] = 'Σημερινά QSOs ';
$lang['dashboard_qso_breakdown'] = 'QSOs Αναλυτικά';
$lang['dashboard_countries_breakdown'] = 'Χώρες Αναλυτικά';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Από την ημερομηνία';

$lang['gen_this_qso_was_confirmed_on'] = 'Αυτό το QSO επιβεβαιώθηκε στις';

$lang['error_no_logbook_found'] = 'Δεν βρέθηκαν αρχεία. Πρέπει να ορίσετε ένα αρχεία στα αρχεία σταθμών! Κάντε το εδώ:';

$lang['copy_to_clipboard'] = 'Αντιγραφή στο πρόχειρο';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';
